#!/usr/bin/env python
# coding=utf-8
'''
brief        :  
Author       : knightdby knightdby@163.com
Date         : 2023-02-24 23:52:36
FilePath     : /manifast/manifast/label_utils/__init__.py
Description  : 
LastEditTime : 2024-04-23 14:39:22
LastEditors  : knightdby
Copyright (c) 2023 by Inc, All Rights Reserved.
'''
from .segment.get_mask_shapes import getPolygonwithMask